@@ -1,7 +1,10 @@
 #' Restart an Application
 #'
+#' @description
 #' Restart an application currently running on a remote server.
 #'
+#' Supported servers: ShinyApps servers
+#'
 #' @param appName Name of application to restart
 #' @param account Account name. If a single account is registered on the system
 #'   then this parameter can be omitted.
@@ -20,16 +23,17 @@
 #' @note This function works only for ShinyApps servers.
 #' @export
 restartApp <- function(appName, account = NULL, server = NULL, quiet = FALSE) {
+  accountDetails <- accountInfo(account, server)
+  checkShinyappsServer(accountDetails$server)
 
   # define deploy task
   taskDef <- list()
   taskDef$beginStatus <- "Restarting application"
   taskDef$endStatus <- "Application successfully restarted"
   taskDef$action <- function(client, application) {
-    client$deployApplication(application$id)
+    client$deployApplication(application)
   }
 
   # perform it
-  applicationTask(taskDef, appName, account, server, quiet)
+  applicationTask(taskDef, appName, accountDetails, quiet)
 }
-
